@@ -75,8 +75,8 @@ pub struct Administrator {
     /// `true` if the administrator can delete messages of other users.
     pub can_delete_messages: bool,
 
-    /// `true` if the administrator can manage voice chats.
-    pub can_manage_voice_chats: bool,
+    /// `true` if the administrator can manage video chats.
+    pub can_manage_video_chats: bool,
 
     /// `true` if the administrator can invite new users to the chat.
     pub can_invite_users: bool,
@@ -394,26 +394,31 @@ impl ChatMemberKind {
         }
     }
 
-    /// Returns `true` if the user can manage voice chats.
+    /// Returns `true` if the user can manage video chats.
     ///
     /// I.e. returns `true` if the user
     /// - is the owner of the chat
     /// - is an administrator in the given chat and has the
-    ///   [`can_manage_voice_chats`] privilege.
+    ///   [`can_manage_video_chats`] privilege.
     /// Returns `false` otherwise.
     ///
-    /// [`can_manage_voice_chats`]: Administrator::can_manage_voice_chats
-    pub fn can_manage_voice_chats(&self) -> bool {
+    /// [`can_manage_video_chats`]: Administrator::can_manage_video_chats
+    pub fn can_manage_video_chats(&self) -> bool {
         match self {
             Self::Owner(_) => true,
             Self::Administrator(Administrator {
-                can_manage_voice_chats,
+                can_manage_video_chats,
                 ..
-            }) => *can_manage_voice_chats,
+            }) => *can_manage_video_chats,
             Self::Member | Self::Restricted(_) | Self::Left | Self::Banned(_) => false,
         }
     }
 
+    #[deprecated(since = "0.6.0", note = "renamed to `can_manage_video_chats`")]
+    pub fn can_manage_voice_chats(&self) -> bool {
+        self.can_manage_video_chats()
+    }
+
     /// Returns `true` if the user can can invite new users to the chat.
     ///
     /// I.e. returns `true` if the user
@@ -612,7 +617,7 @@ mod tests {
             "can_manage_chat": true,
             "can_change_info": true,
             "can_delete_messages": true,
-            "can_manage_voice_chats": true,
+            "can_manage_video_chats": true,
             "can_invite_users": true,
             "can_restrict_members": true,
             "can_pin_messages": true,
@@ -636,7 +641,7 @@ mod tests {
                 can_post_messages: None,
                 can_edit_messages: None,
                 can_delete_messages: true,
-                can_manage_voice_chats: true,
+                can_manage_video_chats: true,
                 can_invite_users: true,
                 can_restrict_members: true,
                 can_pin_messages: Some(true),
